Rapporti | OiRA

Temi

# Rapporti

Tista’ tuża rapport biex:

- tipprovdi evidenza lill-awtoritajiet superviżorji;
- tgħaddi informazzjoni lill-persuni kkonċernati (ħaddiema, rappreżentanti tas-sigurtà, impjegaturi, esperti fis-saħħa u s-sigurtà fuq il-post tax-xogħol, eċċ.);
- tissorvelja u tivvaluta jekk ġewx introdotti l-miżuri meħtieġa;
- tirreġistra kwalunkwe reviżjoni jekk jinbidlu ċ-ċirkostanzi (magni/ħaddiema ġodda, jew bħala riżultat tas-sejbiet ta’ kwalunkwe investigazzjoni ta’ aċċident, eċċ.).

Tista’ tissejvja r-rapport fuq il-kompjuter tiegħek u tistampah. Tista’ wkoll timmodifikah jew iżżid aktar informazzjoni. Jekk jogħġbok innota li kwalunkwe bidla li ssir f’rapport li tkun niżżilt MA TIĠIX issejvjata fl-għodda tal-OiRA.

## Għażliet ta’ rapporti

Hemm tipi differenti ta’ rapporti disponibbli għal skopijiet differenti. L-għażla tar-rapporti disponibbli għall-għodod speċifiċi tiddependi mid-deċiżjonijiet meħuda mis-sieħeb nazzjonali/mill-iżviluppatur tal-għodda tal-OiRA.

Ir-rapporti disponibbli.

### Rapport sħiħ

Format: Word / Office Open XML (.docx). Jista’ jiġi editjat minnek wara li tniżżlu.

Ipprovdi: l-informazzjoni u l-inputs kollha mdaħħla minnek matul il-proċess tal-valutazzjoni tar-riskji.

Użah biex: tipprovdi evidenza tal-valutazzjoni tar-riskji għall-awtoritajiet superviżorji (eż. l-ispettorat tax-xogħol).

### Pjan ta’ azzjoni

Format: Excel / Office Open XML (.xlsx). Jista’ jiġi editjat minnek wara li tniżżlu

Ipprovdi: informazzjoni dwar il-miżuri kollha li tkun għażilt li timplimenta.

Użah biex:

- issegwi b’mod attiv l-implimentazzjoni tal-miżuri li tkun għażilt;
- tiġġestixxi l-problemi/ir-riskji fuq il-post tax-xogħol tiegħek (kompiti speċifiċi, għarfien espert, responsabbiltajiet, skadenzi).

### Ħarsa ġenerali lejn ir-riskji

Format: Portable Document Format (.pdf). Ma jistax jiġi editjat minnek wara li tniżżlu.

Ipprovdi: ħarsa ġenerali lejn ir-riskji identifikati

Użah biex:

- tikseb ħarsa ġenerali ta’ malajr lejn l-istatus tar-riskji fuq il-post tax-xogħol tiegħek;
- tgħaddi informazzjoni lill-persuni kkonċernati;
- tissorvelja jekk ir-riskji/il-miżuri humiex indirizzati kif suppost.

### Ħarsa ġenerali lejn il-miżuri

Format: Portable Document Format (.pdf). Ma jistax jiġi editjat minnek wara li tniżżlu.

Ipprovdi: ħarsa ġenerali ta’ malajr lejn il-miżuri li għandhom jiġu implimentati.

Użah biex:

- tikseb ħarsa ġenerali ta’ malajr tal-istatus tal-miżuri li tkun iddeċidejt li timplimenta;
- tgħaddi informazzjoni lill-persuni kkonċernati;
- tissorvelja jekk ir-riskji/il-miżuri humiex indirizzati kif suppost.

Scroll to top Load toolbar…
Back

## 4-reports.md

Help

Standard search Advanced search

- Splash and Shine Cleaners Last saved 19 days ago based on EU Cleaning More
- Commercial Guardinng, Leicester Last saved 2 months ago based on Private Security EU More
- Private Security, Grafton Street Last saved 2 months ago based on Private Security EU More
- Office operations in times of COVID-19 Last saved 4 months ago based on COVID-19 More